@@ -48,7 +48,7 @@ in which buttons can be placed.
 #include "AColor.h"
 #include "ImageManipulation.h"
 #include "Project.h"
-#include "../commands/CommandManager.h"
+#include "CommandManager.h"
 #include "../widgets/AButton.h"
 #include "../widgets/Grabber.h"
 #include "Prefs.h"
@@ -810,54 +810,18 @@ void ToolBar::MakeRecoloredImageSize(teBmps eBmpOut, teBmps eBmpIn, const wxSize
 
 void ToolBar:: MakeButtonBackgroundsLarge()
 {
-
-   bool bUseAqua = false;
-
-#ifdef EXPERIMENTAL_THEME_PREFS
-   gPrefs->Read( wxT("/GUI/ShowMac"), &bUseAqua, false);
-#endif
-
-#ifdef USE_AQUA_THEME
-   bUseAqua = !bUseAqua;
-#endif
-
-   if( bUseAqua ){
-      MakeMacRecoloredImage( bmpRecoloredUpLarge,       bmpMacUpButton );
-      MakeMacRecoloredImage( bmpRecoloredDownLarge,     bmpMacDownButton );
-      MakeMacRecoloredImage( bmpRecoloredUpHiliteLarge, bmpMacHiliteUpButton );
-      MakeMacRecoloredImage( bmpRecoloredHiliteLarge,   bmpMacHiliteButton );
-   } else {
       MakeRecoloredImage( bmpRecoloredUpLarge,       bmpUpButtonLarge );
       MakeRecoloredImage( bmpRecoloredDownLarge,     bmpDownButtonLarge );
       MakeRecoloredImage( bmpRecoloredUpHiliteLarge, bmpHiliteUpButtonLarge );
       MakeRecoloredImage( bmpRecoloredHiliteLarge,   bmpHiliteButtonLarge );
-   }
 }
 
 void ToolBar::MakeButtonBackgroundsSmall()
 {
-
-   bool bUseAqua = false;
-
-#ifdef EXPERIMENTAL_THEME_PREFS
-   gPrefs->Read( wxT("/GUI/ShowMac"), &bUseAqua, false);
-#endif
-
-#ifdef USE_AQUA_THEME
-   bUseAqua = !bUseAqua;
-#endif
-
-   if( bUseAqua ){
-      MakeMacRecoloredImage( bmpRecoloredUpSmall,       bmpMacUpButtonSmall );
-      MakeMacRecoloredImage( bmpRecoloredDownSmall,     bmpMacDownButtonSmall );
-      MakeMacRecoloredImage( bmpRecoloredUpHiliteSmall, bmpMacHiliteUpButtonSmall );
-      MakeMacRecoloredImage( bmpRecoloredHiliteSmall,   bmpMacHiliteButtonSmall );
-   } else {
       MakeRecoloredImage(    bmpRecoloredUpSmall,       bmpUpButtonSmall );
       MakeRecoloredImage(    bmpRecoloredDownSmall,     bmpDownButtonSmall );
       MakeRecoloredImage(    bmpRecoloredUpHiliteSmall, bmpHiliteUpButtonSmall );
       MakeRecoloredImage(    bmpRecoloredHiliteSmall,   bmpHiliteButtonSmall );
-   }
 }
 
 /// Makes a button and its four different state bitmaps
@@ -927,7 +891,7 @@ AButton * ToolBar::MakeButton(ToolBar *parent,
       wxWindowID( id ),
       wxDefaultPosition, processdownevents,
       theTheme.ImageSize( bmpRecoloredUpLarge ));
-   r->SetLabel( label );
+   r->SetLabel(XO(""));
    enum {
       deflation =
 #ifdef __WXMAC__
